Fixnum

Struct Fixnum 

pub struct Fixnum(/* private fields */);
A type representing an integer within the interval [-230, 230).

Implementations

Source

impl Fixnum

pub fn from_le_bytes(is_negative: bool, le_bytes: &[u8]) -> Option<Self>

Attempts to create a new Fixnum from a sign and little-endian bytes. Will fail if the represented integer is outside of the interval [-230, 230).